translate.storage.base

Package translate :: Package storage :: Module base |
[hide private]
[frames] | no frames]

# Module base

source code

Base classes for storage interfaces.

Organization: Zuza Software Foundation

Copyright: 2006-2009 Zuza Software Foundation

License: GPL

Classes | [hide private]
| ParseError
| TranslationUnit Base class for translation units.
| TranslationStore Base class for stores for multiple translation units of type UnitClass.

Functions | [hide private]
force_override(method, baseclass) Forces derived classes to override method. | source code

Imports: pickle, NotImplementedError, translate, StringElem, general, rich_parse, accepts, Self, IsOneOf, multistring